@@ -229,7 +229,9 @@ async fn read_mnst_by_rel_props<RequestCtx: RequestContext>(mut client: Client<R
         .create_node(
             "Project",
             "__typename id name", Some("1234"),
-            &json!({"name": "Project Zero", "activity": [ { "props": { "repo": "Repo Zero" }, "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, { "props": { "repo": "Repo One" },  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
+            &json!({"name": "Project Zero", 
+                    "activity": [ {"repo": "Repo Zero", "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, 
+                                  {"repo": "Repo One",  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
         .await
         .unwrap();
 
@@ -240,8 +242,8 @@ async fn read_mnst_by_rel_props<RequestCtx: RequestContext>(mut client: Client<R
     let projects = client
         .read_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
-            Some(&json!({"activity": {"props": {"repo": {"EQ": "Repo Zero"}}}}))
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            Some(&json!({"activity": {"repo": {"EQ": "Repo Zero"}}}))
         )
         .await
         .unwrap();
@@ -265,7 +267,7 @@ async fn read_mnst_by_rel_props<RequestCtx: RequestContext>(mut client: Client<R
         .all(|a| a.get("__typename").unwrap() == "ProjectActivityRel"));
     assert!(activity
         .iter()
-        .any(|a| a.get("props").unwrap().get("repo").unwrap() == "Repo Zero"));
+        .any(|a| a.get("repo").unwrap() == "Repo Zero"));
     assert!(activity
         .iter()
         .all(|a| a.get("dst").unwrap().get("__typename").unwrap() == "Commit"));
@@ -282,7 +284,8 @@ async fn read_mnst_by_dst_props<RequestCtx: RequestContext>(mut client: Client<R
         .create_node(
             "Project",
             "__typename id name", Some("1234"),
-            &json!({"name": "Project Zero", "activity": [ { "props": { "repo": "Repo Zero" }, "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, { "props": { "repo": "Repo One" },  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
+            &json!({"name": "Project Zero", "activity": [ { "repo": "Repo Zero", "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, 
+                                                          { "repo": "Repo One",  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
         .await
         .unwrap();
 
@@ -293,7 +296,7 @@ async fn read_mnst_by_dst_props<RequestCtx: RequestContext>(mut client: Client<R
     let projects = client
         .read_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
             Some(&json!({"activity": {"dst": {"Commit": {"hash": {"EQ": "11111"}}}}}))
         )
         .await
@@ -318,7 +321,7 @@ async fn read_mnst_by_dst_props<RequestCtx: RequestContext>(mut client: Client<R
         .all(|a| a.get("__typename").unwrap() == "ProjectActivityRel"));
     assert!(activity
         .iter()
-        .any(|a| a.get("props").unwrap().get("repo").unwrap() == "Repo One"));
+        .any(|a| a.get("repo").unwrap() == "Repo One"));
     assert!(activity
         .iter()
         .all(|a| a.get("dst").unwrap().get("__typename").unwrap() == "Commit"));
@@ -371,14 +374,15 @@ async fn update_mnst_new_node<RequestCtx: RequestContext>(mut client: Client<Req
         .create_node(
             "Project",
             "__typename id name", Some("1234"),
-            &json!({"name": "Project Zero", "activity": [ { "props": { "repo": "Repo Zero" }, "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, { "props": { "repo": "Repo One" },  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
+            &json!({"name": "Project Zero", "activity": [ { "repo": "Repo Zero", "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, 
+                                                          { "repo": "Repo One",  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
         .await
         .unwrap();
 
     let pu = client
         .update_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
             Some(&json!({"name": {"EQ": "Project Zero"}})),
             &json!({"activity": {"ADD": {"dst": {"Commit": {"NEW": {"hash": "22222"}}}}}})
         )
@@ -423,7 +427,8 @@ async fn update_mnst_existing_node<RequestCtx: RequestContext>(mut client: Clien
         .create_node(
             "Project",
             "__typename id name", Some("1234"),
-            &json!({"name": "Project Zero", "activity": [ { "props": { "repo": "Repo Zero" }, "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, { "props": { "repo": "Repo One" },  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
+            &json!({"name": "Project Zero", "activity": [ { "repo": "Repo Zero", "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, 
+                                                          { "repo": "Repo One",  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
         .await
         .unwrap();
 
@@ -440,7 +445,7 @@ async fn update_mnst_existing_node<RequestCtx: RequestContext>(mut client: Clien
     let pu = client
         .update_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
             Some(&json!({"name": {"EQ": "Project Zero"}})),
             &json!({"activity": {"ADD": {"dst": {"Commit": {"EXISTING": {"hash": {"EQ": "22222"}}}}}}})
         )
@@ -485,16 +490,17 @@ async fn update_mnst_relationship<RequestCtx: RequestContext>(mut client: Client
         .create_node(
             "Project",
             "__typename id name", Some("1234"),
-            &json!({"name": "Project Zero", "activity": [ { "props": { "repo": "Repo Zero" }, "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, { "props": { "repo": "Repo One" },  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
+            &json!({"name": "Project Zero", "activity": [ { "repo": "Repo Zero", "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, 
+                                                          { "repo": "Repo One",  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
         .await
         .unwrap();
 
     let pu = client
         .update_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
             Some(&json!({"name": {"EQ": "Project Zero"}})),
-            &json!({"activity": {"UPDATE": {"MATCH": {"dst": {"Commit": {"hash": {"EQ": "00000"}}}}, "SET": {"props": {"repo": "Repo 0"}}}}})
+            &json!({"activity": {"UPDATE": {"MATCH": {"dst": {"Commit": {"hash": {"EQ": "00000"}}}}, "SET": {"repo": "Repo 0"}}}})
         )
         .await
         .unwrap();
@@ -524,12 +530,10 @@ async fn update_mnst_relationship<RequestCtx: RequestContext>(mut client: Client
     assert!(activityu
         .iter()
         .any(|a| a.get("dst").unwrap().get("hash").unwrap() == "11111"));
+    assert!(activityu.iter().any(|a| a.get("repo").unwrap() == "Repo 0"));
     assert!(activityu
         .iter()
-        .any(|a| a.get("props").unwrap().get("repo").unwrap() == "Repo 0"));
-    assert!(activityu
-        .iter()
-        .all(|a| a.get("props").unwrap().get("repo").unwrap() != "Repo Zero"));
+        .all(|a| a.get("repo").unwrap() != "Repo Zero"));
 }
 
 /// Passes if warpgrapher can delete a relationship by its properties
@@ -541,8 +545,9 @@ async fn delete_mnst_relationship_by_rel_props<RequestCtx: RequestContext>(
     let p0 = client
         .create_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
-            &json!({"name": "Project Zero", "activity": [ { "props": { "repo": "Repo Zero" }, "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, { "props": { "repo": "Repo One" },  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            &json!({"name": "Project Zero", "activity": [ { "repo": "Repo Zero", "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, 
+                                                          { "repo": "Repo One", "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
         .await
         .unwrap();
 
@@ -557,9 +562,9 @@ async fn delete_mnst_relationship_by_rel_props<RequestCtx: RequestContext>(
     let pu = client
         .update_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
             Some(&json!({"name": {"EQ": "Project Zero"}})),
-            &json!({"activity": {"DELETE": {"MATCH": {"props": {"repo": {"EQ": "Repo Zero"}}}}}})
+            &json!({"activity": {"DELETE": {"MATCH": {"repo": {"EQ": "Repo Zero"}}}}})
         )
         .await
         .unwrap();
@@ -591,10 +596,10 @@ async fn delete_mnst_relationship_by_rel_props<RequestCtx: RequestContext>(
         .any(|a| a.get("dst").unwrap().get("hash").unwrap() == "11111"));
     assert!(activityu
         .iter()
-        .all(|a| a.get("props").unwrap().get("repo").unwrap() != "Repo Zero"));
+        .all(|a| a.get("repo").unwrap() != "Repo Zero"));
     assert!(activityu
         .iter()
-        .any(|a| a.get("props").unwrap().get("repo").unwrap() == "Repo One"));
+        .any(|a| a.get("repo").unwrap() == "Repo One"));
 }
 
 /// Passes if warpgrapher can delete a relationship by the properties of the dst object
@@ -606,8 +611,9 @@ async fn delete_mnst_relationship_by_dst_props<RequestCtx: RequestContext>(
     let p0 = client
         .create_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
-            &json!({"name": "Project Zero", "activity": [ { "props": { "repo": "Repo Zero" }, "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, { "props": { "repo": "Repo One" },  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            &json!({"name": "Project Zero", "activity": [ { "repo": "Repo Zero", "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, 
+                                                          { "repo": "Repo One",  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
         .await
         .unwrap();
 
@@ -622,7 +628,7 @@ async fn delete_mnst_relationship_by_dst_props<RequestCtx: RequestContext>(
     let pu = client
         .update_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
             Some(&json!({"name": {"EQ":"Project Zero"}})),
             &json!({"activity": {"DELETE": {"MATCH": {"dst": {"Commit": {"hash": {"EQ": "00000"}}}}}}})
         )
@@ -656,10 +662,10 @@ async fn delete_mnst_relationship_by_dst_props<RequestCtx: RequestContext>(
         .any(|a| a.get("dst").unwrap().get("hash").unwrap() == "11111"));
     assert!(activityu
         .iter()
-        .all(|a| a.get("props").unwrap().get("repo").unwrap() != "Repo Zero"));
+        .all(|a| a.get("repo").unwrap() != "Repo Zero"));
     assert!(activityu
         .iter()
-        .any(|a| a.get("props").unwrap().get("repo").unwrap() == "Repo One"));
+        .any(|a| a.get("repo").unwrap() == "Repo One"));
 }
 
 /// Passes if warpgrapher can delete a node by the properties of a relationship
@@ -671,8 +677,9 @@ async fn delete_node_by_mnst_rel_property<RequestCtx: RequestContext>(
     let p0 = client
         .create_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
-            &json!({"name": "Project Zero", "activity": [ { "props": { "repo": "Repo Zero" }, "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, { "props": { "repo": "Repo One" },  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            &json!({"name": "Project Zero", "activity": [ { "repo": "Repo Zero", "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, 
+                                                          { "repo": "Repo One",  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
         .await
         .unwrap();
 
@@ -697,7 +704,7 @@ async fn delete_node_by_mnst_rel_property<RequestCtx: RequestContext>(
     let projects = client
         .read_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }",  Some("1234"),
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }",  Some("1234"),
             None,
         )
         .await
@@ -717,8 +724,9 @@ async fn delete_node_by_mnst_dst_property<RequestCtx: RequestContext>(
     let p0 = client
         .create_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }",  Some("1234"),
-            &json!({"name": "Project Zero", "activity": [ { "props": { "repo": "Repo Zero" }, "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, { "props": { "repo": "Repo One" },  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }",  Some("1234"),
+            &json!({"name": "Project Zero", "activity": [ { "repo": "Repo Zero", "dst": { "Commit": { "NEW": { "hash": "00000" } } } }, 
+                                                          { "repo": "Repo One",  "dst": { "Commit": {"NEW": { "hash": "11111" }}}} ] }))
         .await
         .unwrap();
 
@@ -743,7 +751,7 @@ async fn delete_node_by_mnst_dst_property<RequestCtx: RequestContext>(
     let projects = client
         .read_node(
             "Project",
-            "__typename id name activity { __typename id props { repo } dst { ...on Commit { __typename id hash } } }", Some("1234"),
+            "__typename id name activity { __typename id repo dst { ...on Commit { __typename id hash } } }", Some("1234"),
             None,
         )
         .await
