@@ -2,11 +2,11 @@ mod setup;
 
 use assert_approx_eq::assert_approx_eq;
 use serde_json::json;
+#[cfg(feature = "cypher")]
+use setup::cypher_test_client;
 #[cfg(feature = "gremlin")]
 use setup::gremlin_test_client;
-#[cfg(feature = "neo4j")]
-use setup::neo4j_test_client;
-#[cfg(any(feature = "gremlin", feature = "neo4j"))]
+#[cfg(any(feature = "gremlin", feature = "cypher"))]
 use setup::{clear_db, init};
 use warpgrapher::client::Client;
 use warpgrapher::engine::context::RequestContext;
@@ -21,13 +21,13 @@ async fn scalar_lists_test_gremlin() {
     scalar_lists_test(client).await;
 }
 
-#[cfg(feature = "neo4j")]
+#[cfg(feature = "cypher")]
 #[tokio::test]
-async fn scalar_lists_test_neo4j() {
+async fn scalar_lists_test_cypher() {
     init();
     clear_db().await;
 
-    let client = neo4j_test_client("./tests/fixtures/scalars/scalar_list.yml").await;
+    let client = cypher_test_client("./tests/fixtures/scalars/scalar_list.yml").await;
     scalar_lists_test(client).await;
 }
 
@@ -90,17 +90,20 @@ async fn scalar_lists_no_array_gremlin() {
     scalar_lists_no_array_test(client).await;
 }
 
-#[cfg(feature = "neo4j")]
+#[cfg(feature = "cypher")]
 #[tokio::test]
-async fn scalar_lists_no_array_neo4j() {
+async fn scalar_lists_no_array_cypher() {
     init();
     clear_db().await;
 
-    let client = neo4j_test_client("./tests/fixtures/scalars/scalar_list.yml").await;
+    let client = cypher_test_client("./tests/fixtures/scalars/scalar_list.yml").await;
     scalar_lists_no_array_test(client).await;
 }
 
-/// Passes if the create mutation and the read query both succeed.
+/// Passes if the create mutation and the read query both succeed. Note, if you want an
+/// array/list on a node, and you're starting with a single element, you still have to send
+/// and array of one element. Sending a single element not wrapped as a list will and should
+/// fail, as it sets a scalar property value rather than a list and is returned as such.
 #[allow(clippy::float_cmp, dead_code)]
 async fn scalar_lists_no_array_test<RequestCtx: RequestContext>(mut client: Client<RequestCtx>) {
     let result = client
@@ -113,10 +116,10 @@ async fn scalar_lists_no_array_test<RequestCtx: RequestContext>(mut client: Clie
             ",
             Some("1234"),
             &json!({
-                "string_list": "string0",
-                "bool_list": false,
-                "int_list": 0,
-                "float_list": 0.0,
+                "string_list": ["string0"],
+                "bool_list": [false],
+                "int_list": [0],
+                "float_list": [0.0],
             }),
         )
         .await
@@ -149,13 +152,13 @@ async fn scalar_no_lists_gremlin() {
     scalar_no_lists_test(client).await;
 }
 
-#[cfg(feature = "neo4j")]
+#[cfg(feature = "cypher")]
 #[tokio::test]
-async fn scalar_no_lists_neo4j() {
+async fn scalar_no_lists_cypher() {
     init();
     clear_db().await;
 
-    let client = neo4j_test_client("./tests/fixtures/scalars/scalar_no_list.yml").await;
+    let client = cypher_test_client("./tests/fixtures/scalars/scalar_no_list.yml").await;
     scalar_no_lists_test(client).await;
 }
 
@@ -221,13 +224,13 @@ async fn scalar_no_lists_no_array_gremlin() {
     scalar_no_lists_no_array_test(client).await;
 }
 
-#[cfg(feature = "neo4j")]
+#[cfg(feature = "cypher")]
 #[tokio::test]
-async fn scalar_no_lists_no_array_neo4j() {
+async fn scalar_no_lists_no_array_cypher() {
     init();
     clear_db().await;
 
-    let client = neo4j_test_client("./tests/fixtures/scalars/scalar_no_list.yml").await;
+    let client = cypher_test_client("./tests/fixtures/scalars/scalar_no_list.yml").await;
     scalar_no_lists_no_array_test(client).await;
 }
 
